/*-------------------------------------------------------------------*/
/*                                                                   */
/*  CL PROGRAM DESCRIPTION...                                        */
/*                                                                   */
/*                                                                   */
/*   PROGRAM ID: CHKJOBSTS                                           */
/*                                                                   */
/*  DESCRIPTION: This program uses the List Job API to check the     */
/*               status of any given Job based solely on the Job     */
/*               Name.  This program will only return information    */
/*               for a Job if it is Active or on the Job Queue.      */
/*                                                                   */
/*-------------------------------------------------------------------*/
/*                                                                   */
/*  PARAMETER USAGE                                                  */
/*  ===============                                                  */
/*                                                                   */
/*   PARM  USAGE  TYPE  LENGTH  DESCRIPTION                          */
/*   -------------------------------------------------------------   */
/*    #1     I    *CHAR   10    Job Name                             */
/*    #2    I/O   *CHAR   10    User Name                            */
/*                                 Values: '          ' (blank)      */
/*                                         Valid User Id             */
/*    #3    I/O   *CHAR    6    Job Number                           */
/*                                 Values: '      '     (blank)      */
/*                                         Valid Job Number          */
/*    #4     O    *CHAR   10    Job Status                           */
/*                                 Values: '          ' (blank)      */
/*                                         '*ACTIVE   '              */
/*                                         '*JOBQ     '              */
/*                                                                   */
/*-------------------------------------------------------------------*/
/*                                                                   */
/*  INDICATOR USAGE                                                  */
/*  ===============                                                  */
/*                                                                   */
/*                                                                   */
/*                                                                   */
/*                                                                   */
/*-------------------------------------------------------------------*/
/*                                                                   */
/*  MODIFICATION HISTORY                                             */
/*  ====================                                             */
/*                                                                   */
/*                                                                   */
/*  MODIFICATION ID: n/a                                             */
/*             DATE: 9 June 1995                                     */
/*       PROGRAMMER: Kevin J. McDaniel                               */
/*                   Computer Associates International, Inc.         */ 
/*                   Global Professional Services                    */ 
/*                   6650 W. Snowville Road                          */
/*                   Brecksville, Ohio  44141                        */
/*                   Tel: 216-838-8200                               */
/*                   Fax: 216-838-4144                               */
/*      DESCRIPTION: Created.                                        */
/*                                                                   */
/*                                                                   */
/*-------------------------------------------------------------------*/
/*                                                                   */
/*  PROGRAM NOTES                                                    */
/*  =============                                                    */
/*                                                                   */
/*  The format used here with API QUSLJOB, will be JOBL0100.         */
/*                                                                   */
/*  Format JOBL0100 contains:                                        */
/*     1 - 10  Job Name                                              */
/*    11 - 20  User Name Used                                        */
/*    21 - 26  Job Number Used                                       */
/*    27 - 42  Internal Job Identifier                               */
/*    43 - 52  Job Status (*** This is what we want)                 */
/*    53 - 53  Job Type                                              */
/*    54 - 54  Job Subtype                                           */
/*    55 - 56  Reserved                                              */
/*                                                                   */
/*-------------------------------------------------------------------*/


 CHKJOBSTS:  PGM        PARM(&JOBNAM &JOBUSR &JOBNBR &JOBSTAT)


/*********************************************************************/
/*         D E C L A R E   P R O G R A M   V A R I A B L E S         */
/*********************************************************************/

  /*------------------------------------*/
 /*  PARAMETER VARIABLES.              */
/*------------------------------------*/

             DCL        VAR(&JOBNAM) TYPE(*CHAR) LEN(10)
             DCL        VAR(&JOBUSR) TYPE(*CHAR) LEN(10)
             DCL        VAR(&JOBNBR) TYPE(*CHAR) LEN(6)
             DCL        VAR(&JOBSTAT) TYPE(*CHAR) LEN(10)

  /*------------------------------------*/
 /*  GENERIC VARIABLES.                */
/*------------------------------------*/

             DCL        VAR(&JOBID) TYPE(*CHAR) LEN(26)
             DCL        VAR(&BIN4) TYPE(*CHAR) LEN(4)
             DCL        VAR(&DEC8) TYPE(*DEC) LEN(8 0)
             DCL        VAR(&LEN) TYPE(*DEC) LEN(8 0)
             DCL        VAR(&LENBIN) TYPE(*CHAR) LEN(4)
             DCL        VAR(&LJENTRY) TYPE(*CHAR) LEN(57)
             DCL        VAR(&LOOP) TYPE(*DEC) LEN(8 0)
             DCL        VAR(&NBR) TYPE(*CHAR) LEN(6)
             DCL        VAR(&STATUS) TYPE(*CHAR) LEN(10)

  /*------------------------------------*/
 /*  USER SPACE VARIABLES.             */
/*------------------------------------*/

             DCL        VAR(&USRSPC) TYPE(*CHAR) LEN(20) +
                          VALUE('LJ        QTEMP     ')
             DCL        VAR(&WRKSPC) TYPE(*CHAR) LEN(10) +

  /*------------------------------------*/
 /*  ERROR HANDLING VARIABLES.         */
/*------------------------------------*/

             DCL        VAR(&MSGID) TYPE(*CHAR) LEN(7)
             DCL        VAR(&MSG) TYPE(*CHAR) LEN(512)
             DCL        VAR(&MSGDTA) TYPE(*CHAR) LEN(512)
             DCL        VAR(&MSGF) TYPE(*CHAR) LEN(10)
             DCL        VAR(&MSGFLIB) TYPE(*CHAR) LEN(10)
             DCL        VAR(&KEYVAR) TYPE(*CHAR) LEN(4)
             DCL        VAR(&KEYVAR2) TYPE(*CHAR) LEN(4)
             DCL        VAR(&RTNTYPE) TYPE(*CHAR) LEN(2)


/*********************************************************************/
/*      G L O B A L   E R R O R   M E S S A G E   M O N I T O R      */
/*********************************************************************/

             MONMSG     MSGID(CPF0000) EXEC(GOTO CMDLBL(STDERR1))


/*********************************************************************/
/*                          M A I N L I N E                          */
/*********************************************************************/

 START:

   /*------------------------------------*/
  /* CREATE A TEMPORARY USER SPACE TO   */
 /*  LIST JOBS IN.                     */
/*------------------------------------*/

             RTVJOBA    NBR(&NBR)
             CHGVAR     VAR(%SST(&USRSPC 3 6)) VALUE(&NBR)
             CHGVAR     VAR(&WRKSPC) VALUE(%SST(&USRSPC 1 10))

         /* TRY TO DELETE USER SPACE BEFORE CREATING IT. */
             DLTUSRSPC  USRSPC(QTEMP/&WRKSPC)
               MONMSG     MSGID(CPF0000)

         /* CREAT THE USER SPACE. */
             CALL       PGM(QUSCRTUS) PARM(&USRSPC 'LJSPACE   ' +
                          X'00000100' ' ' '*ALL      ' 'LJ +
                          Temporary User Space')
                 /*----------------------------------------*/
                 /* CREATE USER SPACE PARMS:               */
                 /*----------------------------------------*/
                 /* USER SPACE NAME AND LIBRARY            */
                 /* EXTENDED ATTRIBUTE (LIKE PF, LF, DSPF) */
                 /* INITIAL SIZE                           */
                 /* INITIAL VALUE                          */
                 /* AUTHORITY                              */
                 /* TEXT                                   */
                 /*----------------------------------------*/

  /*------------------------------------*/
 /*  GET INFO ABOUT A SPECIFIC JOB.    */
/*------------------------------------*/

             IF         COND(&JOBUSR *EQ ' ') THEN(CHGVAR +
                          VAR(&JOBUSR) VALUE('*ALL      '))
             IF         COND(&JOBNBR *EQ ' ') THEN(CHGVAR +
                          VAR(&JOBNBR) VALUE('*ALL  '))

             CHGVAR     VAR(&JOBID) VALUE(&JOBNAM *CAT &JOBUSR +
                          *CAT &JOBNBR)

         /* USE LIST JOB API. */
             CALL       PGM(QUSLJOB) PARM(&USRSPC 'JOBL0100  ' +
                          &JOBID '*ALL      ')
                 /*----------------------------------------*/
                 /* LIST JOB PARMS:                        */
                 /*----------------------------------------*/
                 /* RECEIVING USER SPACE NAME AND LIBRARY  */
                 /* FORMAT NAME OF INFORMATION TO RECEIVE  */
                 /* QUALIFIED JOB NAME                     */
                 /* JOB STATUS                             */
                 /*----------------------------------------*/

  /*------------------------------------*/
 /*  SEE IF ANY JOB INFO WAS FOUND.    */
/*------------------------------------*/

         /* LOOK AT HEADER PORTION TO SEEI IF ANY JOB INFO WAS FOUND. */
             CALL       PGM(QUSRTVUS) PARM(&USRSPC X'00000085' +
                          X'00000004' &BIN4)
                 /*----------------------------------------*/
                 /* RETREIVE USER SPACE PARMS:             */
                 /*----------------------------------------*/
                 /* USER SPACE NAME AND LIBRARY            */
                 /* OFFSET TO # OF ENTRIES - 133 IN HEADER */
                 /* LENGTH OF DATA TO RECEIVE              */
                 /* VAR TO RECEIVE VALUE OF # OF ENTRIES   */
                 /*----------------------------------------*/

   /*------------------------------------*/
  /*  IF NO ENTRIES WERE FOUND, THEN    */
 /*   SET THE RETURN CODE AND EXIT.    */
/*------------------------------------*/

             CHGVAR     VAR(&LOOP) VALUE(%BINARY(&BIN4))

             IF         COND(&LOOP *EQ 0) THEN(DO)
               CHGVAR     VAR(&JOBSTAT) VALUE('          ')
               GOTO       CMDLBL(ALLDONE)
               ENDDO

       /*------------------------------------*/
      /* OK, JOBS WERE FOUND, BUT ARE THEY  */
     /* ACTIVE OR ON THE JOBQ?  WE COULD   */
    /* HAVE LOOKED JUST FOR ACTIVE JOBS   */
   /* WITH THE LIST JOB API BUT THIS     */
  /* WOULD HAVE MISSED ANYTHING WAITING */
 /* ON THE JOBQ.                       */
/*------------------------------------*/

         /* RETREIVE THE LIST ENTRY LENGTH FROM HEADER OF USER SPACE. */
             CALL       PGM(QUSRTVUS) PARM(&USRSPC X'00000089' +
                          X'00000004' &LENBIN)
                 /*----------------------------------------*/
                 /* RETREIVE USER SPACE PARMS:             */
                 /*----------------------------------------*/
                 /* USER SPACE NAME AND LIBRARY            */
                 /* OFFSET TO SIZE OF ENTRIES - 137 IN HDR */
                 /* LENGTH OF DATA TO RECEIVE              */
                 /* VAR TO RECEIVE VALUE OF ENTRY SIZE     */
                 /*----------------------------------------*/

             CHGVAR     VAR(&LEN) VALUE(%BINARY(&LENBIN))

         /* RETREIVE THE OFFSET TO THE LIST PORTION OF THE USER SPACE. */
             CALL       PGM(QUSRTVUS) PARM(&USRSPC X'0000007D' +
                          X'00000004' &BIN4)
                 /*----------------------------------------*/
                 /* RETREIVE USER SPACE PARMS:             */
                 /*----------------------------------------*/
                 /* USER SPACE NAME AND LIBRARY            */
                 /* OFFSET TO LIST ENTRY - 125 IN HEADER   */
                 /* LENGTH OF DATA TO RECEIVE              */
                 /* VAR TO RECEIVE VALUE OF LIST OFFSET    */
                 /*----------------------------------------*/

             CHGVAR     VAR(&DEC8) VALUE(%BINARY(&BIN4))
             CHGVAR     VAR(&DEC8) VALUE(&DEC8 + 1)

  /*------------------------------------*/
 /*  RETREIVE LIST INFORMATION.        */
/*------------------------------------*/

 STARTLOOP:  CHGVAR     VAR(%BINARY(&BIN4)) VALUE(&DEC8)

         /* RETREIVE THE ACTUAL LIST ENTRY FROM THE USER SPACE. */
             CALL       PGM(QUSRTVUS) PARM(&USRSPC &BIN4 +
                          &LENBIN &LJENTRY)
                 /*----------------------------------------*/
                 /* RETREIVE USER SPACE PARMS:             */
                 /*----------------------------------------*/
                 /* USER SPACE NAME AND LIBRARY            */
                 /* OFFSET TO LIST ENTRY                   */
                 /* LENGTH OF DATA TO RECEIVE              */
                 /* VAR TO RECEIVE VALUE OF LIST ENTRY     */
                 /*----------------------------------------*/

             CHGVAR     VAR(&STATUS) VALUE(%SST(&LJENTRY 43 10))

             IF         COND((&STATUS *EQ '*ACTIVE   ') *OR +
                             (&STATUS *EQ '*JOBQ     ')) THEN(DO)
               CHGVAR     VAR(&JOBUSR) VALUE(%SST(&LJENTRY 11 10))
               CHGVAR     VAR(&JOBNBR) VALUE(%SST(&LJENTRY 21 6))
               CHGVAR     VAR(&JOBSTAT) VALUE(&STATUS)
               GOTO       CMDLBL(ALLDONE)
               ENDDO

 ENDLOOP:    CHGVAR     VAR(&DEC8) VALUE(&DEC8 + &LEN)
             CHGVAR     VAR(&LOOP) VALUE(&LOOP - 1)

             IF         COND(&LOOP *EQ 0) THEN(DO)
               CHGVAR     VAR(&JOBSTAT) VALUE('          ')
               GOTO       CMDLBL(ALLDONE)
               ENDDO

             GOTO       CMDLBL(STARTLOOP)

  /*------------------------------------*/
 /*  CLEAN UP AFTER OURSELVES.         */
/*------------------------------------*/

 ALLDONE:    DLTUSRSPC  USRSPC(QTEMP/&WRKSPC)
               MONMSG     MSGID(CPF0000)

             GOTO       CMDLBL(ENDPGM)


/*********************************************************************/
/*                E R R O R   H A N D L I N G                        */
/*********************************************************************/

 STDERR1:    DMPCLPGM

 STDERR2:    RCVMSG     PGMQ(*PRV) MSGKEY(&KEYVAR) RMV(*NO) +
                          KEYVAR(&KEYVAR2) MSG(&MSG) +
                          MSGDTA(&MSGDTA) MSGID(&MSGID) +
                          RTNTYPE(&RTNTYPE) MSGF(&MSGF) +
                          SNDMSGFLIB(&MSGFLIB)

             IF         COND(&RTNTYPE *NE '02') THEN(GOTO +
                          CMDLBL(STDERR3))

             IF         COND(&MSGID *NE ' ') THEN(SNDPGMMSG +
                          MSGID(&MSGID) MSGF(&MSGFLIB/&MSGF) +
                          MSGDTA(&MSGDTA) MSGTYPE(*DIAG))

             IF         COND(&MSGID *EQ ' ') THEN(SNDPGMMSG +
                          MSG(&MSG) MSGTYPE(*DIAG))

             RMVMSG     MSGKEY(&KEYVAR2)

 STDERR3:    RCVMSG     MSGKEY(&KEYVAR) MSGDTA(&MSGDTA) +
                          MSGID(&MSGID) MSGF(&MSGF) +
                          SNDMSGFLIB(&MSGFLIB)
             SNDPGMMSG  MSGID(&MSGID) MSGF(&MSGFLIB/&MSGF) +
                          MSGDTA(&MSGDTA) MSGTYPE(*ESCAPE)


/*********************************************************************/
/*                  P R O G R A M   E N D                            */
/*********************************************************************/

 ENDPGM:     ENDPGM
 
